pyxmpp2.sasl.plain.PlainClientAuthenticator

Package pyxmpp2 :: Package sasl :: Module plain :: Class PlainClientAuthenticator |
[hide private]

# Class PlainClientAuthenticator

Provides PLAIN SASL authentication for a client.

Nested Classes | [hide private]
Inherited from `core.ClientAuthenticator`: `__metaclass__`

Instance Methods | [hide private]
__init__(self, password_manager) Initialize a PlainClientAuthenticator object. |
sasl.Response or sasl.Failure |
start(self, username, authzid) Start the authentication process and return the initial response. |
sasl.Response or sasl.Failure |
challenge(self, challenge) Process the challenge and return the response. |
Success |
finish(self, data) Handle authentication succes information from the server. |
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| _abc_cache = `<_weakrefset.WeakSet object at 0x879058c>`
| _pyxmpp_sasl_preference = `50`
| _pyxmpp_sasl_secure = `10`
Inherited from `core.ClientAuthenticator`: `__abstractmethods__` Inherited from `core.ClientAuthenticator` (private): `_abc_negative_cache`, `_abc_negative_cache_version`, `_abc_registry`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, password_manager) (Constructor) |
Initialize a PlainClientAuthenticator object. Parameters: `password_manager` (PasswordManager) - name of the password manager object providing authentication credentials. Overrides: object.__init__

### start(self, username, authzid) |
Start the authentication process and return the initial response. Parameters: `username` (`unicode`) - username (authentication id). `authzid` (`unicode`) - authorization id. Returns: sasl.Response or sasl.Failure the initial response or a failure indicator. Overrides: core.ClientAuthenticator.start

### challenge(self, challenge) |
Process the challenge and return the response. Parameters: `challenge` (`str`) - the challenge. Returns: sasl.Response or sasl.Failure the response or a failure indicator. Overrides: core.ClientAuthenticator.challenge

### finish(self, data) |
Handle authentication succes information from the server. Parameters: `data` (`str`) - the optional additional data returned with the success. Returns: Success a success indicator. Overrides: core.ClientAuthenticator.finish